@@ -262,6 +262,24 @@ def getClassFullName(classItem):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
+def getTempWorkspace(clearOneDayBefore=True):
+    baseWorkspaceFoler = getPath(os.path.expanduser("~"), "beniutils.workspace")
+    makeFolder(baseWorkspaceFoler)
+    nowTime = int(time.time() * 10000000)
+    if clearOneDayBefore:
+        oneDayBeforeTime = nowTime - 24 * 60 * 60 * 10000000
+        for folderName in os.listdir(baseWorkspaceFoler):
+            if int(folderName) < oneDayBeforeTime:
+                remove(getPath(baseWorkspaceFoler, folderName))
+    for i in range(100):
+        nowTime += i
+        workspaceFolder = getPath(baseWorkspaceFoler, str(nowTime))
+        if not os.path.exists(workspaceFolder):
+            makeFolder(workspaceFolder)
+            return workspaceFolder
+    raise Exception("创建tempWorkspace目录失败")
+
+
 def execute(*pars, showCmd=True, ignoreError=False):
     cmd = ' '.join(pars)
     if showCmd:
